==> gs2-java-cdk-1.0.35-sources.jar: io/gs2/cdk/skillTree/ref/NamespaceRef.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.skillTree.ref;

import io.gs2.cdk.core.func.GetAttr;
import io.gs2.cdk.core.func.Join;
import io.gs2.cdk.skillTree.ref.NodeModelRef;
import io.gs2.cdk.skillTree.stampSheet.MarkReleaseByUserId;
import io.gs2.cdk.skillTree.stampSheet.MarkRestrainByUserId;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class NamespaceRef {
    private String namespaceName;

    public NamespaceRef(
        String namespaceName
    ) {
        this.namespaceName = namespaceName;
    }

    public NodeModelRef nodeModel(
        String nodeModelName
    ) {
        return (new NodeModelRef(
            this.namespaceName,
            nodeModelName
        ));
    }

    public MarkReleaseByUserId markRelease(
        List<String> nodeModelNames,
        String userId
    ) {
        return (new MarkReleaseByUserId(
            this.namespaceName,
            nodeModelNames,
            userId
        ));
    }


    public MarkReleaseByUserId markRelease(
        List<String> nodeModelNames
    ) {
        return (new MarkReleaseByUserId(
            this.namespaceName,
            nodeModelNames,
            "#{userId}"
        ));
    }

    public MarkRestrainByUserId markRestrain(
        List<String> nodeModelNames,
        String userId
    ) {
        return (new MarkRestrainByUserId(
            this.namespaceName,
            nodeModelNames,
            userId
        ));
    }


    public MarkRestrainByUserId markRestrain(
        List<String> nodeModelNames
    ) {
        return (new MarkRestrainByUserId(
            this.namespaceName,
            nodeModelNames,
            "#{userId}"
        ));
    }

    public String grn(
    ) {
        return (new Join(
            ":",
            Arrays.asList(
                "grn",
                "gs2",
                GetAttr.region(
                ).str(
                ),
                GetAttr.ownerId(
                ).str(
                ),
                "skillTree",
                this.namespaceName
            )
        )).str(
        );
    }
}

==> gs2-java-cdk-1.0.58-sources.jar: io/gs2/cdk/skillTree/ref/NamespaceRef.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.skillTree.ref;

import io.gs2.cdk.core.func.GetAttr;
import io.gs2.cdk.core.func.Join;
import io.gs2.cdk.skillTree.ref.NodeModelRef;
import io.gs2.cdk.skillTree.stampSheet.MarkReleaseByUserId;
import io.gs2.cdk.skillTree.stampSheet.MarkRestrainByUserId;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class NamespaceRef {
    private String namespaceName;

    public NamespaceRef(
        String namespaceName
    ) {
        this.namespaceName = namespaceName;
    }

    public NodeModelRef nodeModel(
        String nodeModelName
    ) {
        return (new NodeModelRef(
            this.namespaceName,
            nodeModelName
        ));
    }

    public MarkReleaseByUserId markRelease(
        String propertyId,
        List<String> nodeModelNames,
        String userId
    ) {
        return (new MarkReleaseByUserId(
            this.namespaceName,
            propertyId,
            nodeModelNames,
            userId
        ));
    }


    public MarkReleaseByUserId markRelease(
        String propertyId,
        List<String> nodeModelNames
    ) {
        return (new MarkReleaseByUserId(
            this.namespaceName,
            propertyId,
            nodeModelNames,
            "#{userId}"
        ));
    }

    public MarkRestrainByUserId markRestrain(
        String propertyId,
        List<String> nodeModelNames,
        String userId
    ) {
        return (new MarkRestrainByUserId(
            this.namespaceName,
            propertyId,
            nodeModelNames,
            userId
        ));
    }


    public MarkRestrainByUserId markRestrain(
        String propertyId,
        List<String> nodeModelNames
    ) {
        return (new MarkRestrainByUserId(
            this.namespaceName,
            propertyId,
            nodeModelNames,
            "#{userId}"
        ));
    }

    public String grn(
    ) {
        return (new Join(
            ":",
            Arrays.asList(
                "grn",
                "gs2",
                GetAttr.region(
                ).str(
                ),
                GetAttr.ownerId(
                ).str(
                ),
                "skillTree",
                this.namespaceName
            )
        )).str(
        );
    }
}
